==> monodevelop_2.0+dfsg.orig.tar.gz: monodevelop-2.0/src/core/MonoDevelop.Projects/MonoDevelop.Projects.Dom/DomCecilEvent.cs <==
//
// DomCecilEvent.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using Mono.Cecil;

namespace MonoDevelop.Projects.Dom
{
	public class DomCecilEvent : MonoDevelop.Projects.Dom.DomEvent
	{
		EventDefinition eventDefinition;
		
		public EventDefinition EventDefinition {
			get {
				return eventDefinition;
			}
		}
		
		public void CleanCecilDefinitions ()
		{
			eventDefinition = null;
		}
		
		public  DomCecilEvent (MonoDevelop.Projects.Dom.IType declaringType, bool keepDefinitions, EventDefinition eventDefinition)
		{
			this.declaringType      = declaringType;
			if (keepDefinitions)
				this.eventDefinition = eventDefinition;
			base.name                = eventDefinition.Name;
			base.Modifiers           = DomCecilType.GetModifiers (eventDefinition.AddMethod);
			base.returnType          = DomCecilMethod.GetReturnType (eventDefinition.EventType);
			DomCecilMethod.AddAttributes (this, eventDefinition.CustomAttributes);
			if (!eventDefinition.IsSpecialName)
				base.Modifiers &= ~MonoDevelop.Projects.Dom.Modifiers.SpecialName;
		}
	}
}

==> monodevelop_2.2.1+dfsg.orig.tar.gz: monodevelop-2.2.1/src/core/MonoDevelop.Projects/MonoDevelop.Projects.Dom/DomCecilEvent.cs <==
//
// DomCecilEvent.cs
//
// Author:
//   Mike Krüger <mkrueger@novell.com>
//
// Copyright (C) 2008 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using Mono.Cecil;

namespace MonoDevelop.Projects.Dom
{
	public class DomCecilEvent : MonoDevelop.Projects.Dom.DomEvent
	{
		EventDefinition eventDefinition;
		
		public EventDefinition EventDefinition {
			get {
				return eventDefinition;
			}
		}
		
		public  DomCecilEvent (EventDefinition eventDefinition)
		{
			this.eventDefinition     = eventDefinition;
			base.name                = eventDefinition.Name;
			base.Modifiers           = DomCecilType.GetModifiers (eventDefinition.AddMethod);
			base.ReturnType          = DomCecilMethod.GetReturnType (eventDefinition.EventType);
			DomCecilMethod.AddAttributes (this, eventDefinition.CustomAttributes);
			if (!eventDefinition.IsSpecialName)
				base.Modifiers &= ~MonoDevelop.Projects.Dom.Modifiers.SpecialName;
		}
	}
}
